@@ -2,7 +2,7 @@ push_textdomain("tribes")
 
 dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "empire_hunters_house",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("empire_building", "Hunter’s House"),
@@ -18,10 +18,13 @@ descriptions:new_productionsite_type {
       granite = 1
    },
 
-   animations = {
+   animation_directory = dirname,
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 54, 55 },
+         frames = 1,
+         columns = 1,
+         rows = 1,
+         hotspot = { 55, 57 },
       },
    },
 
@@ -36,7 +39,7 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start hunting because ...
-         descname = _"hunting",
+         descname = _("hunting"),
          actions = {
             "callworker=hunt",
             "sleep=duration:35s"
@@ -45,9 +48,9 @@ descriptions:new_productionsite_type {
    },
    out_of_resource_notification = {
       -- Translators: Short for "Out of Game" for a resource
-      title = _"No Game",
+      title = _("No Game"),
       -- TRANSLATORS: "Game" means animals that you can hunt
-      heading = _"Out of Game",
+      heading = _("Out of Game"),
       -- TRANSLATORS: "game" means animals that you can hunt
       message = pgettext("empire_building", "The hunter working out of this hunter’s house can’t find any game in his work area."),
       productivity_threshold = 0
