@@ -2,7 +2,7 @@ push_textdomain("tribes")
 
 dirname = path.dirname(__file__)
 
-descriptions:new_immovable_type {
+wl.Descriptions():new_immovable_type {
    name = "cornfield_harvested",
    -- TRANSLATORS: This is an immovable name used in lists of immovables
    descname = pgettext("immovable", "Cornfield (harvested)"),
@@ -14,12 +14,15 @@ descriptions:new_immovable_type {
       }
    },
 
-   animations = {
+   animation_directory = dirname,
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 34, 22 },
+         frames = 5,
+         rows = 3,
+         columns = 2,
+         hotspot = { 34, 22 }
       },
-   }
+   },
 }
 
 pop_textdomain()
