@@ -2,15 +2,15 @@ push_textdomain("tribes")
 
 dirname = path.dirname(__file__)
 
-descriptions:new_ware_type {
+wl.Descriptions():new_ware_type {
    name = "hammer",
    -- TRANSLATORS: This is a ware name used in lists of wares
    descname = pgettext("ware", "Hammer"),
    icon = dirname .. "menu.png",
 
+   animation_directory = dirname,
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle.png"),
          hotspot = { 3, 4 },
       },
    }
