@@ -181,6 +181,94 @@
 --
 --    dirname = path.dirname(__file__)
 --
+--    spritesheets = {
+--       atk_fail_e = {
+--          fps = 10,
+--          frames = 10,
+--          rows = 4,
+--          columns = 3,
+--          hotspot = { 13, 35 }
+--       },
+--       atk_fail_w = {
+--          fps = 10,
+--          frames = 10,
+--          rows = 4,
+--          columns = 3,
+--          hotspot = { 36, 39 }
+--       },
+--       atk_ok_e = {
+--          fps = 10,
+--          frames = 10,
+--          rows = 4,
+--          columns = 3,
+--          hotspot = { 13, 36 }
+--       },
+--       atk_ok_w = {
+--          fps = 10,
+--          frames = 10,
+--          rows = 4,
+--          columns = 3,
+--          hotspot = { 36, 39 }
+--       },
+--       die_e = {
+--          fps = 10,
+--          frames = 20,
+--          rows = 5,
+--          columns = 4,
+--          hotspot = { 10, 36 }
+--       },
+--       die_w = {
+--          fps = 10,
+--          frames = 20,
+--          rows = 5,
+--          columns = 4,
+--          hotspot = { 10, 36 }
+--       },
+--       eva_fail_e = {
+--          fps = 10,
+--          frames = 10,
+--          rows = 4,
+--          columns = 3,
+--          hotspot = { 14, 27 }
+--       },
+--       eva_fail_w = {
+--          fps = 10,
+--          frames = 10,
+--          rows = 4,
+--          columns = 3,
+--          hotspot = { 34, 26 }
+--       },
+--       eva_ok_e = {
+--          fps = 20,
+--          frames = 20,
+--          rows = 5,
+--          columns = 4,
+--          hotspot = { 21, 28 }
+--       },
+--       eva_ok_w = {
+--          fps = 20,
+--          frames = 20,
+--          rows = 5,
+--          columns = 4,
+--          hotspot = { 31, 31 }
+--       },
+--       idle = {
+--          fps = 5,
+--          frames = 40,
+--          rows = 7,
+--          columns = 6,
+--          hotspot = { 10, 32 }
+--       },
+--       walk = {
+--          fps = 10,
+--          frames = 10,
+--          rows = 4,
+--          columns = 3,
+--          directional = true,
+--          hotspot = { 19, 27 }
+--       },
+--    }
+--
 --    all_levels_atl = {
 --       min_health = 0,
 --       min_attack = 0,
@@ -192,30 +280,14 @@
 --       max_evade = 2,
 --    }
 --
---    descriptions:new_soldier_type {
+--    wl.Descriptions():new_soldier_type {
 --       name = "atlanteans_soldier",
 --       descname = pgettext("atlanteans_worker", "Soldier"),
 --       animation_directory = dirname,
 --       icon = dirname .. "menu.png",
 --       vision_range = 2,
 --
---       animations = {
---          idle = { hotspot = { 10, 36 } },
---          atk_ok_e   = { hotspot = { 36, 40 } },
---          atk_fail_e = { hotspot = { 36, 40 } },
---          eva_ok_e   = { hotspot = { 36, 40 } },
---          eva_fail_e = { hotspot = { 36, 40 } },
---          atk_ok_w   = { hotspot = { 36, 40 } },
---          atk_fail_w = { hotspot = { 36, 40 } },
---          eva_ok_w   = { hotspot = { 36, 40 } },
---          eva_fail_w = { hotspot = { 36, 40 } },
---          die_w = { hotspot = { 10, 36 } },
---          die_e = { hotspot = { 10, 36 } },
---          walk = {
---             hotspot = { 20, 34 },
---             directional = true
---          }
---       }
+--       spritesheets = spritesheets,
 --
 --       -- Battle attributes - initial values and per level increase
 --       health = {
@@ -297,67 +369,92 @@ push_textdomain("tribes")
 
 dirname = path.dirname(__file__)
 
-animations = {
-   idle = {
-      pictures = path.list_files(dirname .. "idle_??.png"),
-      hotspot = { 10, 36 },
-      fps = 5
-   },
-   atk_ok_e = {
-      pictures = path.list_files(dirname .. "atk_ok_e_??.png"),
-      hotspot = { 36, 40 },
-      fps = 10
-   },
+spritesheets = {
    atk_fail_e = {
-      pictures = path.list_files(dirname .. "atk_fail_e_??.png"),
-      hotspot = { 36, 40 },
-      fps = 10
-   },
-   eva_ok_e = {
-      pictures = path.list_files(dirname .. "eva_ok_e_??.png"),
-      hotspot = { 36, 40 },
-      fps = 20
-   },
-   eva_fail_e = {
-      pictures = path.list_files(dirname .. "eva_fail_e_??.png"),
-      hotspot = { 36, 40 },
-      fps = 10
-   },
-   atk_ok_w = {
-      pictures = path.list_files(dirname .. "atk_ok_w_??.png"),
-      hotspot = { 36, 40 },
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 13, 35 }
    },
    atk_fail_w = {
-      pictures = path.list_files(dirname .. "atk_fail_w_??.png"),
-      hotspot = { 36, 40 },
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 36, 39 }
    },
-   eva_ok_w = {
-      pictures = path.list_files(dirname .. "eva_ok_w_??.png"),
-      hotspot = { 36, 40 },
-      fps = 20
+   atk_ok_e = {
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 13, 36 }
    },
-   eva_fail_w = {
-      pictures = path.list_files(dirname .. "eva_fail_w_??.png"),
-      hotspot = { 36, 40 },
-      fps = 10
-   },
-   die_w = {
-      pictures = path.list_files(dirname .. "die_??.png"),
-      hotspot = { 10, 36 },
-      fps = 10
+   atk_ok_w = {
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 36, 39 }
    },
    die_e = {
-      pictures = path.list_files(dirname .. "die_??.png"),
-      hotspot = { 10, 36 },
-      fps = 10
+      fps = 10,
+      frames = 20,
+      rows = 5,
+      columns = 4,
+      hotspot = { 10, 36 }
+   },
+   die_w = {
+      fps = 10,
+      frames = 20,
+      rows = 5,
+      columns = 4,
+      hotspot = { 10, 36 }
+   },
+   eva_fail_e = {
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 14, 27 }
+   },
+   eva_fail_w = {
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 34, 26 }
+   },
+   eva_ok_e = {
+      fps = 20,
+      frames = 20,
+      rows = 5,
+      columns = 4,
+      hotspot = { 21, 28 }
+   },
+   eva_ok_w = {
+      fps = 20,
+      frames = 20,
+      rows = 5,
+      columns = 4,
+      hotspot = { 31, 31 }
+   },
+   idle = {
+      fps = 5,
+      frames = 40,
+      rows = 7,
+      columns = 6,
+      hotspot = { 10, 32 }
    },
    walk = {
-      hotspot = { 20, 34 },
       fps = 10,
-      directional = true
-   }
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      directional = true,
+      hotspot = { 19, 27 }
+   },
 }
 
 all_levels_atl = {
@@ -371,7 +468,7 @@ all_levels_atl = {
    max_evade = 2,
 }
 
-descriptions:new_soldier_type {
+wl.Descriptions():new_soldier_type {
    name = "atlanteans_soldier",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext("atlanteans_worker", "Soldier"),
@@ -379,7 +476,7 @@ descriptions:new_soldier_type {
    icon = dirname .. "menu.png",
    vision_range = 2,
 
-   animations = animations,
+   spritesheets = spritesheets,
 
    -- Battle attributes - initial values and per level increase
    health = {
