@@ -2,7 +2,7 @@ push_textdomain("tribes")
 
 dirname = path.dirname(__file__)
 
-descriptions:new_worker_type {
+wl.Descriptions():new_worker_type {
    name = "barbarians_cattlebreeder",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext("barbarians_worker", "Cattle Breeder"),
@@ -18,18 +18,27 @@ descriptions:new_worker_type {
       idle = {
          hotspot = { 3, 21 },
       },
+   },
+
+   spritesheets = {
       walk = {
-         hotspot = { 42, 30 },
          fps = 20,
-         directional = true
+         frames = 20,
+         rows = 5,
+         columns = 4,
+         directional = true,
+         hotspot = { 42, 30 }
       },
       walkload = {
          basename = "walk",
-         hotspot = { 42, 30 },
          fps = 20,
-         directional = true
-      }
-   }
+         frames = 20,
+         rows = 5,
+         columns = 4,
+         directional = true,
+         hotspot = { 42, 30 }
+      },
+   },
 }
 
 pop_textdomain()
