@@ -4,36 +4,36 @@ include "txts/help/common_helptexts.lua"
 push_textdomain("texts")
 tips = {
    {
-      text = _"The building process will only start after a road is built to the construction site.",
+      text = _("The building process will only start after a road is built to the construction site."),
       seconds = 4
    },
    {
-      text = _"Be sure to send a geologist to survey sites before building a well or a mine.",
+      text = _("Be sure to send a geologist to survey sites before building a well or a mine."),
       seconds = 4
    },
    {
-      text = _"Your territory can be expanded by building various military buildings – Sentry, Fortress, Blockhouse, etc.",
+      text = _("Your territory can be expanded by building various military buildings – Sentry, Fortress, Blockhouse, etc."),
       seconds = 5
    },
    {
-      text = _"Miners will work only if supplied with food.",
+      text = _("Miners will work only if supplied with food."),
       seconds = 3
    },
    {
-      text = _"Split your roads into shorter sections by planting some flags. This will speed up transportation of your wares.",
+      text = _("Split your roads into shorter sections by planting some flags. This will speed up transportation of your wares."),
       seconds = 6
    },
    {
       -- TRANSLATORS: %s = URL to the Widelands website
-      text = (_"Any further questions? Our FAQ, the wiki and of course our community forums can be found online at %s."):bformat(u("widelands.org")),
+      text = (_("Any further questions? Our FAQ, the wiki and of course our community forums can be found online at %s.")):bformat(u("widelands.org")),
       seconds = 6
    },
    {
-      text = _"Use the priority sliders in building windows to adjust delivery of a specific ware. Holding down Shift while clicking will adjust all wares at once.",
+      text = _("Use the priority sliders in building windows to adjust delivery of a specific ware. Holding down Shift while clicking will adjust all wares at once."),
       seconds = 7
    },
    {
-      text = _"Use the ‘configure economy’ menu to adjust the target quantity of wares. It can be accessed via the flag menu.",
+      text = _("Use the ‘configure economy’ menu to adjust the target quantity of wares. It can be accessed via the flag menu."),
       seconds = 7
    },
    {
@@ -46,15 +46,15 @@ tips = {
       seconds = 4
    },
    {
-      text = _"Removing a road while holding Ctrl lets you remove all flags up to the first junction.",
+      text = _("Removing a road while holding Ctrl lets you remove all flags up to the first junction."),
       seconds = 4
    },
    {
-      text = _"New soldiers are recruited in a barracks. Their abilities can then be improved in training sites.",
+      text = _("New soldiers are recruited in a barracks. Their abilities can then be improved in training sites."),
       seconds = 6
    },
    {
-      text = _"If you like to live dangerously, pressing Ctrl while clicking the enhance, dismantle or destroy building buttons will skip the confirmation.",
+      text = _("If you like to live dangerously, pressing Ctrl while clicking the enhance, dismantle or destroy building buttons will skip the confirmation."),
       seconds = 6
    },
    {
@@ -62,11 +62,11 @@ tips = {
       seconds = 4
    },
    {
-      text = _"An economy consists of all buildings and flags connected by roads. The supplies and demands of buildings are handled in its economy.",
+      text = _("An economy consists of all buildings and flags connected by roads. The supplies and demands of buildings are handled in its economy."),
       seconds = 8
    },
    {
-      text = _"Some buildings, such as the farm, have a very small work area. If the building is surrounded with trees or roads, production will stop.",
+      text = _("Some buildings, such as the farm, have a very small work area. If the building is surrounded with trees or roads, production will stop."),
       seconds = 7
    },
    {
@@ -95,7 +95,7 @@ tips = {
       seconds = 4
    },
    {
-      text = _"When a building is destroyed, its workers will start looking for a nearby flag from which they can move by road to a connected warehouse. If there are no such flags in the vicinity, they will keep wandering around and eventually die.",
+      text = _("When a building is destroyed, its workers will start looking for a nearby flag from which they can move by road to a connected warehouse. If there are no such flags in the vicinity, they will keep wandering around and eventually die."),
       seconds = 7
    },
 
