@@ -4,12 +4,13 @@ dirname = path.dirname(__file__)
 
 wl.Descriptions():new_immovable_type{
    name = "debris01",
-   descname = _ "Debris",
+   descname = _("Debris"),
    size = "small",
    programs = {},
+   animation_directory = dirname,
+   icon = dirname .. "menu.png",
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle.png"),
          hotspot = { 35, 35 },
       },
    }
