@@ -4,12 +4,13 @@ dirname = path.dirname(__file__)
 
 wl.Descriptions():new_immovable_type{
    name = "standing_stone1_winter",
-   descname = _ "Standing Stone",
+   descname = _("Standing Stone"),
    size = "big",
    programs = {},
+   animation_directory = dirname,
+   icon = dirname .. "menu.png",
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle.png"),
          hotspot = { 20, 52 },
       },
    }
